/build/qt6-quickcontrols-nemo/src/qtquickcontrols-nemo/src/controls/.qsb/qml/shaders/NemoIcon.frag.qsb: \
  /build/qt6-quickcontrols-nemo/src/qtquickcontrols-nemo/src/controls/qml/shaders/NemoIcon.frag